/*
 * Copyright (C) 2022  Aravinth Manivannan <realaravinth@batsense.net>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
use async_trait::async_trait;

use libconductor::*;

#[derive(Clone, Debug, PartialEq, Eq)]
pub struct DummyConductor;

const DUMMY_CONDUCTOR_NAME: &str = "DUMMY_CONDUCTOR";

#[async_trait]
impl Conductor for DummyConductor {
    async fn process(&self, event: EventType) {
        println!("Received event: {:?}", event);
    }
    fn name(&self) -> &'static str {
        DUMMY_CONDUCTOR_NAME
    }

    async fn health(&self) -> bool {
        true
    }
}
#[cfg(test)]
mod tests {

    use super::*;

    #[tokio::test]
    async fn all_good() {
        let c = DummyConductor {};
        assert_eq!(c.name(), DUMMY_CONDUCTOR_NAME);
        assert!(c.health().await);
    }
}
